#
# spec file for package rclone
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


Name:           rclone
Version:        1.51.0
Release:        lp152.1.4
Summary:        Rsync for cloud storage
License:        MIT
Group:          Productivity/Networking/Web/Utilities
URL:            https://rclone.org/
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  go >= 1.11

%description
rsync for cloud storage. rclone is a command line program to sync files and
directories to and from a wide variety of cloud storage providers, providing
various additional features.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%setup -q

%build
go build -o %{name} -mod=vendor -buildmode=pie

./%{name} genautocomplete bash completion.bash
./%{name} genautocomplete zsh  completion.zsh

%install
install -m0755 -D %{name} %{buildroot}%{_bindir}/%{name}
install -m0644 -D %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

install -m0644 -D completion.bash %{buildroot}%{_datadir}/bash/%{name}
install -m0644 -D completion.zsh  %{buildroot}%{_datadir}/zsh/_%{name}

%fdupes %{buildroot}

%files
%doc MANUAL.md README.md RELEASE.md
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files bash-completion
%{_datadir}/bash/

%files zsh-completion
%{_datadir}/zsh/

%changelog
* Sat Feb  1 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.51.0
  * See https://rclone.org/changelog/#v1-51-0-2020-02-01 for the
    complete changelog.
* Tue Nov 19 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.50.2
  * Bug Fixes
  - accounting: Fix memory leak on retries operations (Nick Craig-Wood)
  * Drive
  - Fix listing of the root directory with drive.files scope (Nick Craig-Wood)
  - Fix --drive-root-folder-id with team/shared drives (Nick Craig-Wood)
* Sat Nov  2 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.50.1
  * Bug Fixes
  - hash: Fix accidentally changed hash names for DropboxHash and CRC-32 (Nick Craig-Wood)
  - fshttp: Fix error reporting on tpslimit token bucket errors (Nick Craig-Wood)
  - fshttp: Don’t print token bucket errors on context cancelled (Nick Craig-Wood)
  * Local
  - Fix listings of . on Windows (Nick Craig-Wood)
  * Onedrive
  - Fix DirMove/Move after Onedrive change (Xiaoxing Ye)
* Sat Oct 26 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.50.0
  * New backends
  - Citrix Sharefile (Nick Craig-Wood)
  - Chunker - an overlay backend to split files into smaller parts (Ivan Andreev)
  - Mail.ru Cloud (Ivan Andreev)
  * New Features
  - encodings (Fabian Möller & Nick Craig-Wood)
  + All backends now use file name encoding to ensure any file name can be written to any backend.
  + See the restricted file name docs for more info and the local backend docs.
  + Some file names may look different in rclone if you are using any control characters in names or unicode FULLWIDTH symbols.
  - build
  + Update to use go1.13 for the build (Nick Craig-Wood)
  + Drop support for go1.9 (Nick Craig-Wood)
  + Build rclone with GitHub actions (Nick Craig-Wood)
  + Convert python scripts to python3 (Nick Craig-Wood)
  + Swap Azure/go-ansiterm for mattn/go-colorable (Nick Craig-Wood)
  + Dockerfile fixes (Matei David)
  + Add plugin support for backends and commands (Richard Patel)
  - config
  + Use alternating Red/Green in config to make more obvious (Nick Craig-Wood)
  - contrib
  + Add sample DLNA server Docker Compose manifest. (pataquets)
  + Add sample WebDAV server Docker Compose manifest. (pataquets)
  - copyurl
  + Add --auto-filename flag for using file name from URL in destination path (Denis)
  - serve dlna:
  + Many compatability improvements (Dan Walters)
  + Support for external srt subtitles (Dan Walters)
  - rc
  + Added command core/quit (Saksham Khanna)
  * Bug Fixes
  - sync
  + Make --update/-u not transfer files that haven’t changed (Nick Craig-Wood)
  + Free objects after they come out of the transfer pipe to save memory (Nick Craig-Wood)
  + Fix --files-from without --no-traverse doing a recursive scan (Nick Craig-Wood)
  - operations
  + Fix accounting for server side copies (Nick Craig-Wood)
  + Display ‘All duplicates removed’ only if dedupe successful (Sezal Agrawal)
  + Display ‘Deleted X extra copies’ only if dedupe successful (Sezal Agrawal)
  - accounting
  + Only allow up to 100 completed transfers in the accounting list to save memory (Nick Craig-Wood)
  + Cull the old time ranges when possible to save memory (Nick Craig-Wood)
  + Fix panic due to server-side copy fallback (Ivan Andreev)
  + Fix memory leak noticeable for transfers of large numbers of objects (Nick Craig-Wood)
  + Fix total duration calculation (Nick Craig-Wood)
  - cmd
  + Fix environment variables not setting command line flags (Nick Craig-Wood)
  + Make autocomplete compatible with bash’s posix mode for macOS (Danil Semelenov)
  + Make --progress work in git bash on Windows (Nick Craig-Wood)
  + Fix ‘compopt: command not found’ on autocomplete on macOS (Danil Semelenov)
  - config
  + Fix setting of non top level flags from environment variables (Nick Craig-Wood)
  + Check config names more carefully and report errors (Nick Craig-Wood)
  + Remove error: can’t use --size-only and --ignore-size together. (Nick Craig-Wood)
  + filter: Prevent mixing options when --files-from is in use (Michele Caci)
  + serve sftp: Fix crash on unsupported operations (eg Readlink) (Nick Craig-Wood)
  * Mount
  - Allow files of unkown size to be read properly (Nick Craig-Wood)
  - Skip tests on <= 2 CPUs to avoid lockup (Nick Craig-Wood)
  - Fix panic on File.Open (Nick Craig-Wood)
  - Fix “mount_fusefs: -o timeout=: option not supported” on FreeBSD (Nick Craig-Wood)
  - Don’t pass huge filenames (>4k) to FUSE as it can’t cope (Nick Craig-Wood)
  * VFS
  - Add flag --vfs-case-insensitive for windows/macOS mounts (Ivan Andreev)
  - Make objects of unknown size readable through the VFS (Nick Craig-Wood)
  - Move writeback of dirty data out of close() method into its own method (FlushWrites) and remove close() call from Flush() (Brett Dutro)
  - Stop empty dirs disappearing when renamed on bucket based remotes (Nick Craig-Wood)
  - Stop change notify polling clearing so much of the directory cache (Nick Craig-Wood)
  * Azure Blob
  - Disable logging to the Windows event log (Nick Craig-Wood)
  * B2
  - Remove unverified: prefix on sha1 to improve interop (eg with CyberDuck) (Nick Craig-Wood)
  * Box
  - Add options to get access token via JWT auth (David)
  * Drive
  - Disable HTTP/2 by default to work around INTERNAL_ERROR problems (Nick Craig-Wood)
  - Make sure that drive root ID is always canonical (Nick Craig-Wood)
  - Fix --drive-shared-with-me from the root with lsand --fast-list (Nick Craig-Wood)
  - Fix ChangeNotify polling for shared drives (Nick Craig-Wood)
  - Fix change notify polling when using appDataFolder (Nick Craig-Wood)
  * Dropbox
  - Make disallowed filenames errors not retry (Nick Craig-Wood)
  - Fix nil pointer exception on restricted files (Nick Craig-Wood)
  * Fichier
  - Fix accessing files > 2GB on 32 bit systems (Nick Craig-Wood)
  * FTP
  - Allow disabling EPSV mode (Jon Fautley)
  * HTTP
  - HEAD directory entries in parallel to speedup (Nick Craig-Wood)
  - Add --http-no-head to stop rclone doing HEAD in listings (Nick Craig-Wood)
  * Putio
  - Add ability to resume uploads (Cenk Alti)
  * S3
  - Fix signature v2_auth headers (Anthony Rusdi)
  - Fix encoding for control characters (Nick Craig-Wood)
  - Only ask for URL encoded directory listings if we need them on Ceph (Nick Craig-Wood)
  - Add option for multipart failiure behaviour (Aleksandar Jankovic)
  - Support for multipart copy (庄天翼)
  - Fix nil pointer reference if no metadata returned for object (Nick Craig-Wood)
  * SFTP
  - Fix --sftp-ask-password trying to contact the ssh agent (Nick Craig-Wood)
  - Fix hashes of files with backslashes (Nick Craig-Wood)
  - Include more ciphers with --sftp-use-insecure-cipher (Carlos Ferreyra)
  * WebDAV
  - Parse and return Sharepoint error response (Henning Surmeier)
* Sun Sep 29 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.4
  * Bug Fixes
  - cmd/rcd: Address ZipSlip vulnerability (Richard Patel)
  - accounting: Fix file handle leak on errors (Nick Craig-Wood)
  - oauthutil: Fix security problem when running with two users on the same machine (Nick Craig-Wood)
  * FTP
  - Fix listing of an empty root returning: error dir not found (Nick Craig-Wood)
  * S3
  - Fix SetModTime on GLACIER/ARCHIVE objects and implement set/get tier (Nick Craig-Wood)
* Sun Sep 15 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.3
  * Bug Fixes
  - accounting
    + Fix total duration calculation (Aleksandar Jankovic)
    + Fix “file already closed” on transfer retries (Nick Craig-Wood)
* Sun Sep  8 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.2
  * New Features
  - build: Add Docker workflow support (Alfonso Montero)
  * Bug Fixes
  - accounting: Fix locking in Transfer to avoid deadlock with --progress (Nick Craig-Wood)
  - docs: Fix template argument for mktemp in install.sh (Cnly)
  - operations: Fix -u/--update with google photos / files of unknown size (Nick Craig-Wood)
  - rc: Fix docs for config/create /update /password (Nick Craig-Wood)
  * Google Cloud Storage
  - Fix need for elevated permissions on SetModTime (Nick Craig-Wood)
* Thu Aug 29 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.1
  * Bug Fixes
  - config: Fix generated passwords being stored as empty password (Nick Craig-Wood)
  - rcd: Added missing parameter for web-gui info logs. (Chaitanya)
  * Googlephotos
  - Fix crash on error response (Nick Craig-Wood)
  * Onedrive
  - Fix crash on error response (Nick Craig-Wood)
* Mon Aug 26 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.49.0
  * New backends
  - 1fichier (Laura Hausmann)
  - Google Photos (Nick Craig-Wood)
  - Putio (Cenk Alti)
  - premiumize.me (Nick Craig-Wood)
  * New Features
  - Experimental web GUI (Chaitanya Bankanhal)
  - Implement --compare-dest & --copy-dest (yparitcher)
  - Implement --suffix without --backup-dir for backup to current dir (yparitcher)
  - config reconnect to re-login (re-run the oauth login) for the backend. (Nick Craig-Wood)
  - config userinfo to discover which user you are logged in as. (Nick Craig-Wood)
  - config disconnect to disconnect you (log out) from the backend. (Nick Craig-Wood)
  - Add --use-json-log for JSON logging (justinalin)
  - Add context propagation to rclone (Aleksandar Jankovic)
  - Reworking internal statistics interfaces so they work with rc jobs (Aleksandar Jankovic)
  - Add Higher units for ETA (AbelThar)
  - Update rclone logos to new design (Andreas Chlupka)
  - hash: Add CRC-32 support (Cenk Alti)
  - help showbackend: Fixed advanced option category when there are no standard options (buengese)
  - ncdu: Display/Copy to Clipboard Current Path (Gary Kim)
  - operations:
    + Run hashing operations in parallel (Nick Craig-Wood)
    + Don’t calculate checksums when using --ignore-checksum (Nick Craig-Wood)
    + Check transfer hashes when using --size-only mode (Nick Craig-Wood)
    + Disable multi thread copy for local to local copies (Nick Craig-Wood)
    + Debug successful hashes as well as failures (Nick Craig-Wood)
  - rc
    + Add ability to stop async jobs (Aleksandar Jankovic)
    + Return current settings if core/bwlimit called without parameters (Nick Craig-Wood)
    + Rclone-WebUI integration with rclone (Chaitanya Bankanhal)
    + Added command line parameter to control the cross origin resource sharing (CORS) in the rcd. (Security Improvement) (Chaitanya Bankanhal)
    + Add anchor tags to the docs so links are consistent (Nick Craig-Wood)
    + Remove _async key from input parameters after parsing so later operations won’t get confused (buengese)
    + Add call to clear stats (Aleksandar Jankovic)
  - rcd
    + Auto-login for web-gui (Chaitanya Bankanhal)
    + Implement --baseurl for rcd and web-gui (Chaitanya Bankanhal)
  - serve dlna
    + Only select interfaces which can multicast for SSDP (Nick Craig-Wood)
    + Add more builtin mime types to cover standard audio/video (Nick Craig-Wood)
    + Fix missing mime types on Android causing missing videos (Nick Craig-Wood)
  - serve ftp
    + Refactor to bring into line with other serve commands (Nick Craig-Wood)
    + Implement --auth-proxy (Nick Craig-Wood)
  - serve http: Implement --baseurl (Nick Craig-Wood)
  - serve restic: Implement --baseurl (Nick Craig-Wood)
  - serve sftp
    + Implement auth proxy (Nick Craig-Wood)
    + Fix detection of whether server is authorized (Nick Craig-Wood)
  - serve webdav
    + Implement --baseurl (Nick Craig-Wood)
    + Support --auth-proxy (Nick Craig-Wood)
  * Bug Fixes
  - Make “bad record MAC” a retriable error (Nick Craig-Wood)
  - copyurl: Fix copying files that return HTTP errors (Nick Craig-Wood)
  - march: Fix checking sub-directories when using --no-traverse (buengese)
  - rc
    + Fix unmarshalable http.AuthFn in options and put in test for marshalability (Nick Craig-Wood)
    + Move job expire flags to rc to fix initalization problem (Nick Craig-Wood)
    + Fix --loopback with rc/list and others (Nick Craig-Wood)
  - rcat: Fix slowdown on systems with multiple hashes (Nick Craig-Wood)
  - rcd: Fix permissions problems on cache directory with web gui download (Nick Craig-Wood)
  * Mount
  - Default --deamon-timout to 15 minutes on macOS and FreeBSD (Nick Craig-Wood)
  - Update docs to show mounting from root OK for bucket based (Nick Craig-Wood)
  - Remove nonseekable flag from write files (Nick Craig-Wood)
  * VFS
  - Make write without cache more efficient (Nick Craig-Wood)
  - Fix --vfs-cache-mode minimal and writes ignoring cached files (Nick Craig-Wood)
  * Local
  - Add --local-case-sensitive and --local-case-insensitive (Nick Craig-Wood)
  - Avoid polluting page cache when uploading local files to remote backends (Michał Matczuk)
  - Don’t calculate any hashes by default (Nick Craig-Wood)
  - Fadvise run syscall on a dedicated go routine (Michał Matczuk)
  * Azure Blob
  - Azure Storage Emulator support (Sandeep)
  - Updated config help details to remove connection string references (Sandeep)
  - Make all operations work from the root (Nick Craig-Wood)
  * B2
  - Implement link sharing (yparitcher)
  - Enable server side copy to copy between buckets (Nick Craig-Wood)
  - Make all operations work from the root (Nick Craig-Wood)
  * Drive
  - Fix server side copy of big files (Nick Craig-Wood)
  - Update API for teamdrive use (Nick Craig-Wood)
  - Add error for purge with --drive-trashed-only (ginvine)
  * Fichier
  - Make FolderID int and adjust related code (buengese)
  * Google Cloud Storage
  - Reduce oauth scope requested as suggested by Google (Nick Craig-Wood)
  - Make all operations work from the root (Nick Craig-Wood)
  * HTTP
  - Add --http-headers flag for setting arbitrary headers (Nick Craig-Wood)
  * Jottacloud
  - Use new api for retrieving internal username (buengese)
  - Refactor configuration and minor cleanup (buengese)
  * Koofr
  - Support setting modification times on Koofr backend. (jaKa)
  * Opendrive
  - Refactor to use existing lib/rest facilities for uploads (Nick Craig-Wood)
  * Qingstor
  - Upgrade to v3 SDK and fix listing loop (Nick Craig-Wood)
  - Make all operations work from the root (Nick Craig-Wood)
  * S3
  - Add INTELLIGENT_TIERING storage class (Matti Niemenmaa)
  - Make all operations work from the root (Nick Craig-Wood)
  * SFTP
  - Add missing interface check and fix About (Nick Craig-Wood)
  - Completely ignore all modtime checks if SetModTime=false (Jon Fautley)
  - Support md5/sha1 with rsync.net (Nick Craig-Wood)
  - Save the md5/sha1 command in use to the config file for efficiency (Nick Craig-Wood)
  - Opt-in support for diffie-hellman-group-exchange-sha256 diffie-hellman-group-exchange-sha1 (Yi FU)
  * Swift
  - Use FixRangeOption to fix 0 length files via the VFS (Nick Craig-Wood)
  - Fix upload when using no_chunk to return the correct size (Nick Craig-Wood)
  - Make all operations work from the root (Nick Craig-Wood)
  - Fix segments leak during failed large file uploads. (nguyenhuuluan434)
  * WebDAV
  - Add --webdav-bearer-token-command (Nick Craig-Wood)
  - Refresh token when it expires with --webdav-bearer-token-command (Nick Craig-Wood)
  - Add docs for using bearer_token_command with oidc-agent (Paul Millar)
* Thu Jun 20 2019 Ismail Dönmez <idonmez@suse.com>
- Fix executable permission
- Update to version 1.48.0
  * New commands
  - serve sftp: Serve an rclone remote over SFTP (Nick Craig-Wood)
  * New Features
  - Multi threaded downloads to local storage (Nick Craig-Wood)
    controlled with --multi-thread-cutoff and --multi-thread-streams
  - Use rclone.conf from rclone executable directory to enable portable use (albertony)
  - Allow sync of a file and a directory with the same name (forgems)
    this is common on bucket based remotes, eg s3, gcs
  - Add --ignore-case-sync for forced case insensitivity (garry415)
  - Implement --stats-one-line-date and --stats-one-line-date-format (Peter Berbec)
  - Log an ERROR for all commands which exit with non-zero status (Nick Craig-Wood)
  - Use go-homedir to read the home directory more reliably (Nick Craig-Wood)
  - Enable creating encrypted config through external script invocation (Wojciech Smigielski)
  - build: Drop support for go1.8 (Nick Craig-Wood)
  - config: Make config create/update encrypt passwords where necessary (Nick Craig-Wood)
  - copyurl: Honor --no-check-certificate (Stefan Breunig)
  - install: Linux skip man pages if no mandb (didil)
  - lsf: Support showing the Tier of the object (Nick Craig-Wood)
  - lsjson
    + Added EncryptedPath to output (calisro)
    + Support showing the Tier of the object (Nick Craig-Wood)
    + Add IsBucket field for bucket based remote listing of the root (Nick Craig-Wood)
  - rc
    + Add --loopback flag to run commands directly without a server (Nick Craig-Wood)
    + Add operations/fsinfo: Return information about the remote (Nick Craig-Wood)
    + Skip auth for OPTIONS request (Nick Craig-Wood)
    + cmd/providers: Add DefaultStr, ValueStr and Type fields (Nick Craig-Wood)
    + jobs: Make job expiry timeouts configurable (Aleksandar Jankovic)
  - serve dlna reworked and improved (Dan Walters)
  - serve ftp: add --ftp-public-ip flag to specify public IP (calistri)
  - serve restic: Add support for --private-repos in serve restic (Florian Apolloner)
  - serve webdav: Combine serve webdav and serve http (Gary Kim)
  - size: Ignore negative sizes when calculating total (Garry McNulty)
  * Bug Fixes
  - Make move and copy individual files obey --backup-dir (Nick Craig-Wood)
  - If --ignore-checksum is in effect, don’t calculate checksum (Nick Craig-Wood)
  - moveto: Fix case-insensitive same remote move (Gary Kim)
  - rc: Fix serving bucket based objects with --rc-serve (Nick Craig-Wood)
  - serve webdav: Fix serveDir not being updated with changes from webdav (Gary Kim)
  * Mount
  - Fix poll interval documentation (Animosity022)
  * VFS
  - Make WriteAt for non cached files work with non-sequential writes (Nick Craig-Wood)
  * Local
  - Only calculate the required hashes for big speedup (Nick Craig-Wood)
  - Log errors when listing instead of returning an error (Nick Craig-Wood)
  - Fix preallocate warning on Linux with ZFS (Nick Craig-Wood)
  * Crypt
  - Make rclone dedupe work through crypt (Nick Craig-Wood)
  - Fix wrapping of ChangeNotify to decrypt directories properly (Nick Craig-Wood)
  - Support PublicLink (rclone link) of underlying backend (Nick Craig-Wood)
  - Implement Optional methods SetTier, GetTier (Nick Craig-Wood)
  * B2
  - Implement server side copy (Nick Craig-Wood)
  - Implement SetModTime (Nick Craig-Wood)
  * Drive
  - Fix move and copy from TeamDrive to GDrive (Fionera)
  - Add notes that cleanup works in the background on drive (Nick Craig-Wood)
  - Add --drive-server-side-across-configs to default back to old server side copy semantics by default (Nick Craig-Wood)
  - Add --drive-size-as-quota to show storage quota usage for file size (Garry McNulty)
  * FTP
  - Add FTP List timeout (Jeff Quinn)
  - Add FTP over TLS support (Gary Kim)
  - Add --ftp-no-check-certificate option for FTPS (Gary Kim)
  * Google Cloud Storage
  - Fix upload errors when uploading pre 1970 files (Nick Craig-Wood)
  * Jottacloud
  - Add support for selecting device and mountpoint. (buengese)
  * Mega
  - Add cleanup support (Gary Kim)
  * Onedrive
  - More accurately check if root is found (Cnly)
  * S3
  - Suppport S3 Accelerated endpoints with --s3-use-accelerate-endpoint (Nick Craig-Wood)
  - Add config info for Wasabi’s EU Central endpoint (Robert Marko)
  - Make SetModTime work for GLACIER while syncing (Philip Harvey)
  * SFTP
  - Add About support (Gary Kim)
  - Fix about parsing of df results so it can cope with -ve results (Nick Craig-Wood)
  - Send custom client version and debug server version (Nick Craig-Wood)
  * WebDAV
  - Retry on 423 Locked errors (Nick Craig-Wood)
* Sun Jun  9 2019 Aleksa Sarai <asarai@suse.com>
- Update to version 1.47.0. boo#1137685
  - New backends
  - Backend for Koofr cloud storage service. (jaKa)
  - New Features
  - Resume downloads if the reader fails in copy (Nick Craig-Wood)
  - Use `--fast-list` for listing operations where it won't use more memory (Nick Craig-Wood)
  - Make `--files-from` traverse the destination unless `--no-traverse` is set (Nick Craig-Wood)
  - Make server side copy account bytes and obey `--max-transfer` (Nick Craig-Wood)
  - Add `--create-empty-src-dirs` flag and default to not creating empty dirs (ishuah)
  - Add client side TLS/SSL flags `--ca-cert`/`--client-cert`/`--client-key` (Nick Craig-Wood)
  - Implement `--suffix-keep-extension` for use with `--suffix` (Nick Craig-Wood)
  - serve dlna: Add connection manager service description to improve compatibility (Dan Walters)
  - lsf: Add 'e' format to show encrypted names and 'o' for original IDs (Nick Craig-Wood)
  - lsjson: Added `--files-only` and `--dirs-only` flags (calistri)
  - rc: Implement operations/publiclink the equivalent of `rclone link` (Nick Craig-Wood)
  - Bug Fixes
  - accounting: Fix total ETA when `--stats-unit bits` is in effect (Nick Craig-Wood)
  - Bash TAB completion
  - Use private custom func to fix clash between rclone and kubectl (Nick Craig-Wood)
  - Fix for remotes with underscores in their names (Six)
  - Fix completion of remotes (Florian Gamböck)
  - Fix autocompletion of remote paths with spaces (Danil Semelenov)
  - serve dlna: Fix root XML service descriptor (Dan Walters)
  - ncdu: Fix display corruption with Chinese characters (Nick Craig-Wood)
  - Add SIGTERM to signals which run the exit handlers on unix (Nick Craig-Wood)
  - rc: Reload filter when the options are set via the rc (Nick Craig-Wood)
  - VFS / Mount
  - Fix FreeBSD: Ignore Truncate if called with no readers and already the correct size (Nick Craig-Wood)
  - Read directory and check for a file before mkdir (Nick Craig-Wood)
  - Shorten the locking window for vfs/refresh (Nick Craig-Wood)
  - Azure Blob
  - Enable MD5 checksums when uploading files bigger than the "Cutoff" (Dr.Rx)
  - Fix SAS URL support (Nick Craig-Wood)
  - B2
  - Allow manual configuration of backblaze downloadUrl (Vince)
  - Ignore already_hidden error on remove (Nick Craig-Wood)
  - Ignore malformed `src_last_modified_millis` (Nick Craig-Wood)
  - Drive
  - Add `--skip-checksum-gphotos` to ignore incorrect checksums on Google Photos (Nick Craig-Wood)
  - Allow server side move/copy between different remotes. (Fionera)
  - Add docs on team drives and `--fast-list` eventual consistency (Nestar47)
  - Fix imports of text files (Nick Craig-Wood)
  - Fix range requests on 0 length files (Nick Craig-Wood)
  - Fix creation of duplicates with server side copy (Nick Craig-Wood)
  - Dropbox
  - Retry blank errors to fix long listings (Nick Craig-Wood)
  - FTP
  - Add `--ftp-concurrency` to limit maximum number of connections (Nick Craig-Wood)
  - Google Cloud Storage
  - Fall back to default application credentials (marcintustin)
  - Allow bucket policy only buckets (Nick Craig-Wood)
  - HTTP
  - Add `--http-no-slash` for websites with directories with no slashes (Nick Craig-Wood)
  - Remove duplicates from listings (Nick Craig-Wood)
  - Fix socket leak on 404 errors (Nick Craig-Wood)
  - Jottacloud
  - Fix token refresh (Sebastian Bünger)
  - Add device registration (Oliver Heyme)
  - Onedrive
  - Implement graceful cancel of multipart uploads if rclone is interrupted (Cnly)
  - Always add trailing colon to path when addressing items, (Cnly)
  - Return errors instead of panic for invalid uploads (Fabian Möller)
  - S3
  - Add support for "Glacier Deep Archive" storage class (Manu)
  - Update Dreamhost endpoint (Nick Craig-Wood)
  - Note incompatibility with CEPH Jewel (Nick Craig-Wood)
  - SFTP
  - Allow custom ssh client config (Alexandru Bumbacea)
  - Swift
  - Obey Retry-After to enable OVH restore from cold storage (Nick Craig-Wood)
  - Work around token expiry on CEPH (Nick Craig-Wood)
  - WebDAV
  - Allow IsCollection property to be integer or boolean (Nick Craig-Wood)
  - Fix race when creating directories (Nick Craig-Wood)
  - Fix About/df when reading the available/total returns 0 (Nick Craig-Wood)
- Add bash-completion and zsh-completion support.
* Thu Mar 14 2019 Marcus Rueckert <mrueckert@suse.de>
- bump required go to 1.11 as we are using the mod support
* Thu Mar 14 2019 Marcus Rueckert <mrueckert@suse.de>
- Update to version 1.46:
  - New backends
  - Support Alibaba Cloud (Aliyun) OSS via the s3 backend (Nick Craig-Wood)
  - New commands
  - serve dlna: serves a remove via DLNA for the local network (nicolov)
  - New Features
  - copy, move: Restore deprecated --no-traverse flag (Nick Craig-Wood)
  - This is useful for when transferring a small number of files into a large destination
  - genautocomplete: Add remote path completion for bash completion (Christopher Peterson & Danil Semelenov)
  - Buffer memory handling reworked to return memory to the OS better (Nick Craig-Wood)
  - Buffer recycling library to replace sync.Pool
  - Optionally use memory mapped memory for better memory shrinking
  - Enable with --use-mmap if having memory problems - not default yet
  - Parallelise reading of files specified by --files-from (Nick Craig-Wood)
  - check: Add stats showing total files matched. (Dario Guzik)
  - Allow rename/delete open files under Windows (Nick Craig-Wood)
  - lsjson: Use exactly the correct number of decimal places in the seconds (Nick Craig-Wood)
  - Add cookie support with cmdline switch --use-cookies for all HTTP based remotes (qip)
  - Warn if --checksum is set but there are no hashes available (Nick Craig-Wood)
  - Rework rate limiting (pacer) to be more accurate and allow bursting (Nick Craig-Wood)
  - Improve error reporting for too many/few arguments in commands (Nick Craig-Wood)
  - listremotes: Remove -l short flag as it conflicts with the new global flag (weetmuts)
  - Make http serving with auth generate INFO messages on auth fail (Nick Craig-Wood)
  - Bug Fixes
  - Fix layout of stats (Nick Craig-Wood)
  - Fix --progress crash under Windows Jenkins (Nick Craig-Wood)
  - Fix transfer of google/onedrive docs by calling Rcat in Copy when size is -1 (Cnly)
  - copyurl: Fix checking of --dry-run (Denis Skovpen)
  - Mount
  - Check that mountpoint and local directory to mount don’t overlap (Nick Craig-Wood)
  - Fix mount size under 32 bit Windows (Nick Craig-Wood)
  - VFS
  - Implement renaming of directories for backends without DirMove (Nick Craig-Wood)
  - now all backends except b2 support renaming directories
  - Implement --vfs-cache-max-size to limit the total size of the cache (Nick Craig-Wood)
  - Add --dir-perms and --file-perms flags to set default permissions (Nick Craig-Wood)
  - Fix deadlock on concurrent operations on a directory (Nick Craig-Wood)
  - Fix deadlock between RWFileHandle.close and File.Remove (Nick Craig-Wood)
  - Fix renaming/deleting open files with cache mode “writes” under Windows (Nick Craig-Wood)
  - Fix panic on rename with --dry-run set (Nick Craig-Wood)
  - Fix vfs/refresh with recurse=true needing the --fast-list flag
  - Local
  - Add support for -l/--links (symbolic link translation) (yair@unicorn)
  - this works by showing links as link.rclonelink - see local backend docs for more info
  - this errors if used with -L/--copy-links
  - Fix renaming/deleting open files on Windows (Nick Craig-Wood)
  - Crypt
  - Check for maximum length before decrypting filename to fix panic (Garry McNulty)
  - Azure Blob
  - Allow building azureblob backend on *BSD (themylogin)
  - Use the rclone HTTP client to support --dump headers, --tpslimit etc (Nick Craig-Wood)
  - Use the s3 pacer for 0 delay in non error conditions (Nick Craig-Wood)
  - Ignore directory markers (Nick Craig-Wood)
  - Stop Mkdir attempting to create existing containers (Nick Craig-Wood)
  - B2
  - cleanup: will remove unfinished large files >24hrs old (Garry McNulty)
  - For a bucket limited application key check the bucket name (Nick Craig-Wood)
  - before this, rclone would use the authorised bucket regardless of what you put on the command line
  - Added --b2-disable-checksum flag (Wojciech Smigielski)
  - this enables large files to be uploaded without a SHA-1 hash for speed reasons
  - Drive
  - Set default pacer to 100ms for 10 tps (Nick Craig-Wood)
  - This fits the Google defaults much better and reduces the 403 errors massively
  - Add --drive-pacer-min-sleep and --drive-pacer-burst to control the pacer
  - Improve ChangeNotify support for items with multiple parents (Fabian Möller)
  - Fix ListR for items with multiple parents - this fixes oddities with vfs/refresh (Fabian Möller)
  - Fix using --drive-impersonate and appfolders (Nick Craig-Wood)
  - Fix google docs in rclone mount for some (not all) applications (Nick Craig-Wood)
  - Dropbox
  - Retry-After support for Dropbox backend (Mathieu Carbou)
  - FTP
  - Wait for 60 seconds for a connection to Close then declare it dead (Nick Craig-Wood)
  - helps with indefinite hangs on some FTP servers
  - Google Cloud Storage
  - Update google cloud storage endpoints (weetmuts)
  - HTTP
  - Add an example with username and password which is supported but wasn’t documented (Nick Craig-Wood)
  - Fix backend with --files-from and non-existent files (Nick Craig-Wood)
  - Hubic
  - Make error message more informative if authentication fails (Nick Craig-Wood)
  - Jottacloud
  - Resume and deduplication support (Oliver Heyme)
  - Use token auth for all API requests Don’t store password anymore (Sebastian Bünger)
  - Add support for 2-factor authentification (Sebastian Bünger)
  - Mega
  - Implement v2 account login which fixes logins for newer Mega accounts (Nick Craig-Wood)
  - Return error if an unknown length file is attempted to be uploaded (Nick Craig-Wood)
  - Add new error codes for better error reporting (Nick Craig-Wood)
  - Onedrive
  - Fix broken support for “shared with me” folders (Alex Chen)
  - Fix root ID not normalised (Cnly)
  - Return err instead of panic on unknown-sized uploads (Cnly)
  - Qingstor
  - Fix go routine leak on multipart upload errors (Nick Craig-Wood)
  - Add upload chunk size/concurrency/cutoff control (Nick Craig-Wood)
  - Default --qingstor-upload-concurrency to 1 to work around bug (Nick Craig-Wood)
  - S3
  - Implement --s3-upload-cutoff for single part uploads below this (Nick Craig-Wood)
  - Change --s3-upload-concurrency default to 4 to increase perfomance (Nick Craig-Wood)
  - Add --s3-bucket-acl to control bucket ACL (Nick Craig-Wood)
  - Auto detect region for buckets on operation failure (Nick Craig-Wood)
  - Add GLACIER storage class (William Cocker)
  - Add Scaleway to s3 documentation (Rémy Léone)
  - Add AWS endpoint eu-north-1 (weetmuts)
  - SFTP
  - Add support for PEM encrypted private keys (Fabian Möller)
  - Add option to force the usage of an ssh-agent (Fabian Möller)
  - Perform environment variable expansion on key-file (Fabian Möller)
  - Fix rmdir on Windows based servers (eg CrushFTP) (Nick Craig-Wood)
  - Fix rmdir deleting directory contents on some SFTP servers (Nick Craig-Wood)
  - Fix error on dangling symlinks (Nick Craig-Wood)
  - Swift
  - Add --swift-no-chunk to disable segmented uploads in rcat/mount (Nick Craig-Wood)
  - Introduce application credential auth support (kayrus)
  - Fix memory usage by slimming Object (Nick Craig-Wood)
  - Fix extra requests on upload (Nick Craig-Wood)
  - Fix reauth on big files (Nick Craig-Wood)
  - Union
  - Fix poll-interval not working (Nick Craig-Wood)
  - WebDAV
  - Support About which means rclone mount will show the correct disk size (Nick Craig-Wood)
  - Support MD5 and SHA1 hashes with Owncloud and Nextcloud (Nick Craig-Wood)
  - Fail soft on time parsing errors (Nick Craig-Wood)
  - Fix infinite loop on failed directory creation (Nick Craig-Wood)
  - Fix identification of directories for Bitrix Site Manager (Nick Craig-Wood)
  - Fix upload of 0 length files on some servers (Nick Craig-Wood)
  - Fix if MKCOL fails with 423 Locked assume the directory exists (Nick Craig-Wood)
* Mon Dec  3 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version v1.45
  * See https://rclone.org/changelog/ for the complete changelog.
* Thu Sep 27 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version v1.43.1
  * See https://rclone.org/changelog/ for the complete changelog.
- Switch to obs_scm
* Sat Jun 23 2018 asarai@suse.com
- Update to rclone v1.42.
  See https://rclone.org/changelog/ for changelog.
- Switch to %%license macro.
* Tue Jun  5 2018 jacobwinski@gmail.com
- Update to rclone v1.41.
  * Too many changes to list, please see
    https://rclone.org/changelog/ for the complete changelog.
* Tue Jun  5 2018 jacobwinski@gmail.com
- Fix spec file causing build error (unresolvable) on Leap 42.3.
* Fri Apr 13 2018 asarai@suse.com
- Update to rclone v1.40.
* Sat Jan 13 2018 asarai@suse.com
- Initial import of rclone v1.39, an rsync-like utility for cloud storage.
